gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] branch master updated: fix #6147


From: gnunet
Subject: [taler-exchange] branch master updated: fix #6147
Date: Thu, 02 Apr 2020 13:47:24 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to branch master
in repository exchange.

The following commit(s) were added to refs/heads/master by this push:
     new a039926b fix #6147
a039926b is described below

commit a039926bb6f022b1467c7059f0b954b64eaaeb5a
Author: Christian Grothoff <address@hidden>
AuthorDate: Thu Apr 2 13:47:21 2020 +0200

    fix #6147
---
 src/util/amount.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/util/amount.c b/src/util/amount.c
index 95b40add..2fc78654 100644
--- a/src/util/amount.c
+++ b/src/util/amount.c
@@ -624,9 +624,9 @@ TALER_amount_to_string (const struct TALER_Amount *amount)
 const char *
 TALER_amount2s (const struct TALER_Amount *amount)
 {
   /* 12 is sufficient for a uint32_t value in decimal; 3 is for ":.\0" */
   static GNUNET_THREAD_LOCAL char result[TALER_AMOUNT_FRAC_LEN
-                                         + TALER_CURRENCY_LEN + 3 + 12];
+                                         + TALER_CURRENCY_LEN + 3 + 24];
   struct TALER_Amount norm;
 
   if (GNUNET_YES != TALER_amount_is_valid (amount))
@@ -624,9 +624,9 @@ TALER_amount_to_string (const struct TALER_Amount *amount)
 TALER_amount2s (const struct TALER_Amount *amount)
 {
-  /* 12 is sufficient for a uint32_t value in decimal; 3 is for ":.\0" */
+  /* 24 is sufficient for a uint64_t value in decimal; 3 is for ":.\0" */
   static GNUNET_THREAD_LOCAL char result[TALER_AMOUNT_FRAC_LEN

-- 
To stop receiving notification emails like this one, please contact
address@hidden.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]